==> nextcloud-app-mail-5.5.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/ka_GE.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "აუცილებელი",
    "Work" : "სამსახური",
    "Personal" : "პირადი",
    "Later" : "მოგვიანებით",
    "Mail" : "ფოსტა",
    "Connecting" : "მყარდება კავშირი",
    "Save" : "შენახვა",
    "Connect" : "დაკავშირება",
    "Password required" : "საჭიროა პაროლი",
    "Name" : "სახელი",
    "Mail address" : "ფოსტის მისამართი",
    "Password" : "პაროლი",
    "IMAP Host" : "IMAP ჰოსტი",
    "None" : "არც ერთი",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP პორტი",
    "IMAP User" : "IMAP მომხმარებელი",
    "IMAP Password" : "IMAP პაროლი",
    "SMTP Host" : "SMTP ჰოსტი",
    "SMTP Port" : "SMTP პორტი",
    "SMTP User" : "SMTP მომხმარებელი",
    "SMTP Password" : "SMTP პაროლი",
    "Aliases" : "სხვანაირი სახელი",
    "Signature" : "ხელმოწერა",
    "Go back" : "უკან დაბრუნება",
    "Cancel" : "უარყოფა",
    "Accounts" : "ანგარიში",
    "Add mail account" : "საფოსტო ანგარიშის დამატება",
    "General" : "ზოგადი",
    "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
    "Register" : "რეგისტრაცია",
    "About" : "ჩვენს შესახებ",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Compose new message" : "ახალი წერილის შედგენა",
    "Newer message" : "უფრო ახალი წერილი",
    "Older message" : "ძველი წერილი",
    "Toggle star" : "ვარსკლავის გადართვა",
    "Toggle unread" : "წაუკითხავის გადართვა",
    "Archive" : "არქივი",
    "Delete" : "გაუქმება",
    "Search" : "ძიება",
    "Send" : "გაგზავნა",
    "Refresh" : "განახლება",
    "Ok" : "კარგი",
    "Select account" : "აირჩიეთ ანგარიში",
    "Subject" : "სათაური",
    "Upload attachment" : "დანართის ატვირთვა",
    "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
    "Choose" : "აირჩიეთ",
    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
    "Confirm" : "დადასტურება",
    "Unfavorite" : "რჩეულებიდან ამოშლა",
    "Favorite" : "რჩეული",
    "Read" : "წაკითხვა",
    "Edit tags" : "შეცვალეთ ტეგები",
    "More actions" : "მეტი ქმედება",
    "Back" : "უკან",
    "Mark as unread" : "წაუკითხავად მონიშვნა",
    "Mark as read" : "წაკითხულად მონიშვნა",
    "All day" : "მთელი დღე",
    "Attendees" : "დამსწრეები",
    "Description" : "აღწერილობა",
    "Create" : "შექმნა",
    "Select" : "არჩევა",
    "Comment" : "კომენტარი",
    "Accept" : "მიღება",
    "Decline" : "ურაყოფა",
    "Remove" : "წაშლა",
    "email" : "ელ-ფოსტა",
    "Today" : "დღეს",
    "Other" : "სხვა",
    "Forward" : "წინ",
    "Translate" : "გადათარგმნეთ",
    "Unnamed" : "უსახელო",
    "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
    "Import into calendar" : "იმპორტი კალენდარში",
    "Download attachment" : "დანართის გადმოწერა",
    "Save to Files" : "შენახვა ფაილებში",
    "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
    "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
    "Move" : "გადატანა",
    "Remove account" : "ანგარიშის გაუქმება",
    "Folder name" : "დირექტორიის სახელი",
    "Saving" : "მიმდინარეობს შენახვა",
    "Show all folders" : "ყველა დირექტორიის ჩვენება",
    "Collapse folders" : "დირექტორიების კოლაფსი",
    "Delete folder" : "ფოლდერის წაშლა",
    "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
    "Rename" : "სახელის შეცვლა",
    "Clear cache" : "კეშის გასუფთავება",
    "New message" : "ახალი წერილი",
    "Reply" : "პასუხი",
    "Retry" : "ვცადოთ ახლიდან",
    "Message" : "წერილი",
    "Copy to clipboard" : "კოპირება ბუფერში",
    "Add" : "დამატება",
    "Clear" : "გასუფთავება",
    "Close" : "დახურვა",
    "Date" : "თარიღი",
    "Tags" : "ტეგები",
    "Select tags" : "აირჩიეთ ტეგები",
    "Custom" : "ინდივიდუალური",
    "Add tag" : "ტეგის დამატება",
    "Recipient" : "მიმღები",
    "Help" : "დახმარება",
    "matches" : "ემთხვევა",
    "Actions" : "მოქმედებები",
    "Priority" : "პრიორიტეტი",
    "delete" : "წაშლა",
    "Edit" : "შეცვლა",
    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
    "Client ID" : "კლიენტის ID",
    "Client secret" : "კლიენტის საიდუმლო",
    "User" : "მომხმარებელი",
    "Host" : "ჰოსტი",
    "Port" : "პორტი",
    "Valid until" : "ვარგისია",
    "Certificate" : "სერტიფიკატი",
    "Submit" : "გაგზავნა",
    "Shared" : "გაზიარებული",
    "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
    "All" : "ყველა",
    "Drafts" : "მონახაზები",
    "Favorites" : "რჩეულები",
    "All inboxes" : "ყველა ინბოქსი",
    "Inbox" : "ინბოქსი",
    "Junk" : "უსარგებლო",
    "Sent" : "გაგზავნილი",
    "Trash" : "ნაგავი",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ახალი წერილი\n{from}-ისგან","%n ახალი წერილი\n{from}-ისგან"],
    "Nextcloud Mail" : "Nextcloud ფოსტა",
    "Message sent" : "წერილი გაგზავნილია",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ვერ ჩაიტვირთა",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}-ის ჩატვირთვისას მოხდა შეცდომა",
    "Could not load your message" : "თქვენი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the desired message" : "სასურველი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the message" : "წერილის ჩატვირთვა ვერ მოხერხდა",
    "Error loading message" : "წერილის ჩატვირთვისას წარმოიშვა შეცდომა",
    "Forwarding to %s" : "გადაგზავნილია %s-ზე",
    "Click here if you are not automatically redirected within the next few seconds." : "იმ შემთხვევაში, თუ რამდენიმე წამის განმავლობაში არ მოხდება ავტომატური გადამისამართება დააწკაპუნეთ აქ.",
    "Redirect" : "გადამისამართება",
    "The link leads to %s" : "ბმულს მიყევხართ %s-ისკენ",
    "Continue to %s" : "%s-ისკენ გაგრძელება"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-mail-5.5.11-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/ka_GE.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "აუცილებელი",
    "Work" : "სამსახური",
    "Personal" : "პირადი",
    "Later" : "მოგვიანებით",
    "Mail" : "ფოსტა",
    "Connecting" : "მყარდება კავშირი",
    "Save" : "შენახვა",
    "Connect" : "დაკავშირება",
    "Password required" : "საჭიროა პაროლი",
    "Name" : "სახელი",
    "Mail address" : "ფოსტის მისამართი",
    "Password" : "პაროლი",
    "IMAP Host" : "IMAP ჰოსტი",
    "None" : "არც ერთი",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP პორტი",
    "IMAP User" : "IMAP მომხმარებელი",
    "IMAP Password" : "IMAP პაროლი",
    "SMTP Host" : "SMTP ჰოსტი",
    "SMTP Port" : "SMTP პორტი",
    "SMTP User" : "SMTP მომხმარებელი",
    "SMTP Password" : "SMTP პაროლი",
    "Aliases" : "სხვანაირი სახელი",
    "Signature" : "ხელმოწერა",
    "Go back" : "უკან დაბრუნება",
    "Cancel" : "უარყოფა",
    "General" : "ზოგადი",
    "Add mail account" : "საფოსტო ანგარიშის დამატება",
    "Newest first" : "ჯერ ახალი",
    "Oldest first" : "ჯერ ძველი",
    "Register" : "რეგისტრაცია",
    "Security" : "უსაფრთხოება",
    "About" : "ჩვენს შესახებ",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Compose new message" : "ახალი წერილის შედგენა",
    "Newer message" : "უფრო ახალი წერილი",
    "Older message" : "ძველი წერილი",
    "Toggle star" : "ვარსკლავის გადართვა",
    "Toggle unread" : "წაუკითხავის გადართვა",
    "Archive" : "არქივი",
    "Delete" : "გაუქმება",
    "Search" : "ძიება",
    "Send" : "გაგზავნა",
    "Refresh" : "განახლება",
    "Ok" : "კარგი",
    "Select account" : "აირჩიეთ ანგარიში",
    "Subject" : "სათაური",
    "Upload attachment" : "დანართის ატვირთვა",
    "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
    "Choose" : "აირჩიეთ",
    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
    "Confirm" : "დადასტურება",
    "Unfavorite" : "რჩეულებიდან ამოშლა",
    "Favorite" : "რჩეული",
    "Read" : "წაკითხვა",
    "Edit tags" : "შეცვალეთ ტეგები",
    "More actions" : "მეტი ქმედება",
    "Back" : "უკან",
    "Mark as unread" : "წაუკითხავად მონიშვნა",
    "Mark as read" : "წაკითხულად მონიშვნა",
    "All day" : "მთელი დღე",
    "Attendees" : "დამსწრეები",
    "Description" : "აღწერილობა",
    "Create" : "შექმნა",
    "Select" : "არჩევა",
    "Comment" : "კომენტარი",
    "Accept" : "მიღება",
    "Decline" : "ურაყოფა",
    "Remove" : "წაშლა",
    "email" : "ელ-ფოსტა",
    "Today" : "დღეს",
    "Other" : "სხვა",
    "Forward" : "წინ",
    "Translate" : "გადათარგმნეთ",
    "Unnamed" : "უსახელო",
    "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
    "Import into calendar" : "იმპორტი კალენდარში",
    "Download attachment" : "დანართის გადმოწერა",
    "Save to Files" : "შენახვა ფაილებში",
    "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
    "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
    "Move" : "გადატანა",
    "Remove account" : "ანგარიშის გაუქმება",
    "Folder name" : "დირექტორიის სახელი",
    "Saving" : "მიმდინარეობს შენახვა",
    "Show all folders" : "ყველა დირექტორიის ჩვენება",
    "Collapse folders" : "დირექტორიების კოლაფსი",
    "Delete folder" : "ფოლდერის წაშლა",
    "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
    "Rename" : "სახელის შეცვლა",
    "Clear cache" : "კეშის გასუფთავება",
    "New message" : "ახალი წერილი",
    "Reply" : "პასუხი",
    "Retry" : "ვცადოთ ახლიდან",
    "Message" : "წერილი",
    "Copy to clipboard" : "კოპირება ბუფერში",
    "Add" : "დამატება",
    "Clear" : "გასუფთავება",
    "Close" : "დახურვა",
    "Date" : "თარიღი",
    "Tags" : "ტეგები",
    "Select tags" : "აირჩიეთ ტეგები",
    "Custom" : "ინდივიდუალური",
    "Add tag" : "ტეგის დამატება",
    "Recipient" : "მიმღები",
    "Help" : "დახმარება",
    "matches" : "ემთხვევა",
    "Actions" : "მოქმედებები",
    "Priority" : "პრიორიტეტი",
    "delete" : "წაშლა",
    "Edit" : "შეცვლა",
    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
    "Client ID" : "კლიენტის ID",
    "Client secret" : "კლიენტის საიდუმლო",
    "User" : "მომხმარებელი",
    "Host" : "ჰოსტი",
    "Port" : "პორტი",
    "Valid until" : "ვარგისია",
    "Certificate" : "სერტიფიკატი",
    "Submit" : "გაგზავნა",
    "Shared" : "გაზიარებული",
    "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
    "All" : "ყველა",
    "Drafts" : "მონახაზები",
    "Favorites" : "რჩეულები",
    "All inboxes" : "ყველა ინბოქსი",
    "Inbox" : "ინბოქსი",
    "Junk" : "უსარგებლო",
    "Sent" : "გაგზავნილი",
    "Trash" : "ნაგავი",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ახალი წერილი\n{from}-ისგან","%n ახალი წერილი\n{from}-ისგან"],
    "Nextcloud Mail" : "Nextcloud ფოსტა",
    "Message sent" : "წერილი გაგზავნილია",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ვერ ჩაიტვირთა",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}-ის ჩატვირთვისას მოხდა შეცდომა",
    "Could not load your message" : "თქვენი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the desired message" : "სასურველი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the message" : "წერილის ჩატვირთვა ვერ მოხერხდა",
    "Error loading message" : "წერილის ჩატვირთვისას წარმოიშვა შეცდომა",
    "Forwarding to %s" : "გადაგზავნილია %s-ზე",
    "Click here if you are not automatically redirected within the next few seconds." : "იმ შემთხვევაში, თუ რამდენიმე წამის განმავლობაში არ მოხდება ავტომატური გადამისამართება დააწკაპუნეთ აქ.",
    "Redirect" : "გადამისამართება",
    "The link leads to %s" : "ბმულს მიყევხართ %s-ისკენ",
    "Continue to %s" : "%s-ისკენ გაგრძელება",
    "Accounts" : "ანგარიში",
    "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები"
},
"nplurals=2; plural=(n!=1);");
